<template>
  <div id="my_modal_1"
       class="absolute overflow-hidden z-50 w-3/4 max-h-full aspect-square left-1/2 top-1/2 transform -translate-y-1/2 -translate-x-1/2 m-auto">
    <div v-if="chat.conversationLabelDialog.type === 'list'" class="w-full h-full relative flex flex-col flex-1 bg-white rounded-xl  shadow-lg border border-gray-200">

      <div class="flex h-14 flex-row relative justify-between p-3 rounded-lg bg-scheme-primary text-white">
        <h3 class="m-0 text-lg text-white w-full text-center">Conversation Label</h3>
        <button @click="closeDialog" class="btn btn-circle btn-sm flex outline-0 border-0 bg-white">
          <svg class="fill-current text-gray-600" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path fill="currentColor" d="M6.4 19L5 17.6l5.6-5.6L5 6.4L6.4 5l5.6 5.6L17.6 5L19 6.4L13.4 12l5.6 5.6l-1.4 1.4l-5.6-5.6L6.4 19Z"/></svg>
        </button>
      </div>
      <div class="flex p-3 relative overflow-y-auto overflow-x-clip">
        <div class="flex flex-wrap gap-y-4 flex-1 gap-x-4 py-6">

          <div class="indicator flex-shrink-0"
               v-for="label in currentLabels">
            <button
                @click="removeLabel(label?.id)"
                :class="`indicator-item badge badge-accent w-6 bg-red-600 border-0 h-6 p-1 btn-xs ${loading ? 'loading' : ''}`">
              <svg class="fill-current text-white" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path fill="currentColor" d="M6.4 19L5 17.6l5.6-5.6L5 6.4L6.4 5l5.6 5.6L17.6 5L19 6.4L13.4 12l5.6 5.6l-1.4 1.4l-5.6-5.6L6.4 19Z"/></svg>
            </button>
            <button
                :class="`btn btn-sm normal-case font-medium whitespace-nowrap border-0 ${label.background_color === label.text_color ? 'bg-red-500 text-white' : ''}`"
                :style="`background: ${label.background_color}; color:${label.text_color}`">
              {{ label.label_name }}
            </button>
          </div>
        </div>
      </div>
    </div>
    <div v-if="chat.conversationLabelDialog.type === 'search'" class="w-full h-full relative flex flex-col flex-1 bg-white rounded-xl  shadow-lg p-3 border border-gray-200">
      <div class="flex w-full flex-row items-center px-2 gap-2 flex-shrink-0 border-2 rounded-xl  border-gray-300">
        <button class="btn btn-circle btn-ghost btn-sm">
          <svg class="fill-current text-scheme-primary" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
            <path fill="currentColor"
                  d="m19.6 21l-6.3-6.3q-.75.6-1.725.95T9.5 16q-2.725 0-4.612-1.888T3 9.5q0-2.725 1.888-4.612T9.5 3q2.725 0 4.612 1.888T16 9.5q0 1.1-.35 2.075T14.7 13.3l6.3 6.3l-1.4 1.4ZM9.5 14q1.875 0 3.188-1.313T14 9.5q0-1.875-1.313-3.188T9.5 5Q7.625 5 6.312 6.313T5 9.5q0 1.875 1.313 3.188T9.5 14Z"/>
          </svg>
        </button>
        <input v-model="keyword" type="text" placeholder="Type here" class="input block focus:outline-0 text-center w-full"/>
        <button v-if="conversationLabels.length == 0"
            @click="createLabels"
            :class="`btn btn-circle btn-outline btn-sm ${loadingCreate ? 'loading' : ''}`">
          <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path fill="currentColor" d="M19 12.998h-6v6h-2v-6H5v-2h6v-6h2v6h6z"/></svg>
        </button>
      </div>
      <div class="h-full relative">
        <div class="flex relative overflow-y-auto overflow-x-clip">
          <div class="flex flex-wrap gap-y-4 flex-1 gap-x-4 py-6">

            <div class="indicator flex-shrink-0"
                 v-for="label in conversationLabels">
              <button
                  v-if="isSelectedLabel(label.id)"
                  class="indicator-item badge badge-accent w-6 bg-green-600 border-0 h-6 p-1 btn-xs">
                <svg class="fill-current text-white" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path fill="currentColor" d="m9.55 18l-5.7-5.7l1.425-1.425L9.55 15.15l9.175-9.175L20.15 7.4L9.55 18Z"/></svg>
              </button>
              <button
                  @click="selectLabels(label?.id)"
                  :class="`btn btn-sm normal-case font-medium whitespace-nowrap border-0 ${label.background_color === label.text_color ? 'bg-red-500 text-white' : ''}`"
                  :style="`background: ${label.background_color}; color:${label.text_color}`">
                {{ label.label_name }}
              </button>
            </div>
          </div>
        </div>
      </div>
      <button @click="assingLabels" :class="`btn btn-block ${loading ? 'loading' : ''}`">Pilih {{ selectedLabel.length > 0 ? `(${selectedLabel.length})` : ''}}</button>
    </div>
  </div>
  <div @click="closeDialog" class="absolute z-40 top-0 left-0 w-full h-full bg-black bg-opacity-20"></div>
</template>
<script setup lang="ts">
import {useChatListStore} from "../../stores/chat_list";
import {onMounted, ref, watch} from "vue";
import debounce from "lodash.debounce";

const chat = useChatListStore()
const keyword = ref("")
const selectedLabel = ref([])
const currentLabels = ref([])
const loading = ref(false)
const loadingCreate = ref(false)

const conversationLabels = ref([])
const closeDialog = () => {
  chat.conversationLabelDialog = {
    isOpen: false,
    type: 'search',
    data: [],
    conversation_id: null,
    id: null
  }
}

const isSelectedLabel = (label) => {
  var arrR = selectedLabel.value.filter(function(ele){
    return ele == label
  });

  return arrR.length > 0;
}

const selectLabels = (labels) => {
  var arrR = selectedLabel.value.filter((ele) => parseInt(ele) == parseInt(labels))

  if (arrR.length <= 0) {
    selectedLabel.value.push(labels)
  } else {
    const newData = []
    selectedLabel.value.map((item) => {
      if (item !== labels) {
        newData.push(item)
      }
    })
    selectedLabel.value = newData
  }
}

const removeLabel = async (id) => {
  loading.value = true
  await chat.sendConversationLabel({
    label: id,
    conversation_id: chat.conversationLabelDialog.conversation_id
  }, "unassign").then((resp) => {
    if (resp?.code == 200) {
      currentLabels.value = resp?.data?.labels
      // const arr = []
      // resp?.data.map((item) => {
      //   arr.push(item)
      // })
      // conversationLabels.value = arr
    }
  })
  loading.value = false
}

const assingLabels = async () => {
  loading.value = true
  await chat.sendConversationLabel({
    labels: selectedLabel.value,
    conversation_id: chat.conversationLabelDialog.conversation_id
  }, "assign").then((resp) => {
    if (resp?.code == 200) {
      selectedLabel.value = []
      searchConversationLabel()
      chat.fetchChatByCustomer(chat.selectedChat, 1, false).then((resp) => {

        // const messageArr = []
        // chat.messages.map((msg) => {
        //   msg['message'] = helpers.whatsappFormatting(helpers.urlify(helpers.decodeMessage(msg.message)))
        //   msg['send_loading'] = false
        //   messageArr.push(msg)
        // })
        // helpers.scrollToBottomChat()
      }).catch((err) => {
      })
      // const arr = []
      // resp?.data.map((item) => {
      //   arr.push(item)
      // })
      // conversationLabels.value = arr
    }
  })
  loading.value = false
}


const createLabels = async () => {
  if (keyword.value.length > 0) {
    loadingCreate.value = true
    await chat.sendConversationLabel({
      label_name: keyword.value,
      conversation_id: chat.conversationLabelDialog.conversation_id
    }, "create").then((resp) => {
      if (resp?.code == 200) {
        keyword.value = ""
        searchConversationLabel()
        // const arr = []
        // resp?.data.map((item) => {
        //   arr.push(item)
        // })
        // conversationLabels.value = arr
      }
    })
    loadingCreate.value = false
  }
}

const searchConversationLabel = async () => {
  await chat.sendConversationLabel({
    name: keyword.value,
    conversation_id: chat.conversationLabelDialog.conversation_id
  }, "search").then((resp) => {
    if (resp?.code == 200) {
      const arr = []
      resp?.data.map((item) => {
        arr.push(item)
      })
      conversationLabels.value = arr
    }
  })
}

onMounted(() => {
  const arr = []
  chat.conversationLabelDialog.data.map((item) => {
    arr.push(item)
  })

  currentLabels.value = arr
  searchConversationLabel()
})
watch(() => chat.conversationLabelDialog.data, (val) => {
  const arr = []
  val.map((item) => {
    arr.push(item?.id)
  })

  currentLabels.value = arr
})
watch(keyword, debounce(async () => {
  await searchConversationLabel()
}, 500))
</script>
